tuplettools.get_first_tuplet_in_proper_parentage_of_component
=============================================================

.. autofunction:: abjad.tools.tuplettools.get_first_tuplet_in_proper_parentage_of_component
